@@ -21,7 +21,7 @@ from rich import box
 from rich.table import Table
 from rich.text import Text
 
-from lean.constants import SECURITY_MASTER_PRODUCT_ID
+from lean.constants import EQUITY_SECURITY_MASTER_PRODUCT_ID, BULK_EQUITY_SECURITY_MASTER_PRODUCT_ID
 from lean.models.pydantic import WrappedBaseModel
 
 
@@ -391,11 +391,17 @@ class QCFullOrganization(WrappedBaseModel):
 
         :return: True if the organization has a Security Master subscription, False if not
         """
+
+        # TODO: This sort of hardcoded product ID checking is not sufficient when we consider
+        # multiple 'Security Master' products. Especially since they will be specific to certain datasources.
+        # For now, simple checks for an equity "Security Master" subscription
+        # Issue created here: https://github.com/QuantConnect/lean-cli/issues/73
+
         data_products_product = next((x for x in self.products if x.name == "Data"), None)
         if data_products_product is None:
             return False
 
-        return any(x.productId == SECURITY_MASTER_PRODUCT_ID for x in data_products_product.items)
+        return any(x.productId in {EQUITY_SECURITY_MASTER_PRODUCT_ID, BULK_EQUITY_SECURITY_MASTER_PRODUCT_ID} for x in data_products_product.items)
 
 
 class QCMinimalOrganization(WrappedBaseModel):
